/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.security.authentication.authservice;

import java.util.Map;

import org.osgi.annotation.versioning.ProviderType;

/**
 * Retains sessions for users.
 */
@ProviderType
public interface SessionStore {

    /**
     * Closes an active session for a user.
     *
     * @param userId the identifier of the user, cannot be <code>null</code>;
     * @param sessionId the identifier of the session to logout, cannot be <code>null</code>.
     * @return <code>true</code> if the session was successfully closed, <code>false</code> otherwise.
     */
    boolean closeSession(String userId, String sessionId);

    /**
     * Tests whether the user has an active session with the given session identifier.
     *
     * @param userId the identifier of the user, cannot be <code>null</code>;
     * @param sessionId the session identifier of the user, cannot be <code>null</code>.
     * @return <code>true</code> if the user has an active session denoted by the given
     *         session identifier, <code>false</code> otherwise.
     */
    boolean containsSession(String userId, String sessionId);

    /**
     * Creates a new session for a user.
     *
     * @param userId the identifier of the user, cannot be <code>null</code>;
     * @param context the optional context information about the login, can be <code>null</code>.
     * @return a new session identifier, cannot be <code>null</code>.
     * @throws SessionStoreException in case the store was unable to create a new session for whatever reason.
     */
    String createSession(String userId, Map<String, String> context) throws SessionStoreException;

}
