/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.security.authentication.authservice;

/**
 * Denotes an exception thrown in case something went wrong when dealing with sessions.
 */
public class SessionStoreException extends AuthenticationException {
    private static final long serialVersionUID = 1L;

    private final String m_userId;

    /**
     * Creates a new {@link SessionStoreException} instance.
     */
    public SessionStoreException(String userId, String code) {
        super(code);
        m_userId = userId;
    }

    /**
     * Creates a new {@link SessionStoreException} instance.
     */
    public SessionStoreException(String userId, String code, String msg) {
        super(code, msg);
        m_userId = userId;
    }

    /**
     * Creates a new {@link SessionStoreException} instance.
     */
    public SessionStoreException(String userId, String code, String msg, Throwable cause) {
        super(code, msg, cause);
        m_userId = userId;
    }

    /**
     * @return the identifier of the user that caused this exception, can be <code>null</code> if the identifier was not known.
     */
    public String getUserId() {
        return m_userId;
    }
}
