/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.security.authentication.authservice.rest.util;

import java.net.URI;
import java.util.Dictionary;

import org.apache.felix.dm.Component;
import org.osgi.service.cm.ConfigurationException;

/**
 * Provides a couple of convenience methods to work with the authentication
 * resource configuration.
 */
public final class ConfigUtil {

	public static boolean getBoolean(Dictionary<String, ?> dict, String key, boolean dflt)
			throws ConfigurationException {
		String val = getString(dict, key, null);
		if (val == null) {
			return dflt;
		}
		return Boolean.parseBoolean(val);
	}

	public static int getInteger(Dictionary<String, ?> dict, String key, int dflt) throws ConfigurationException {
		String val = getString(dict, key, null);
		if (val == null) {
			return dflt;
		}
		try {
			return Integer.parseInt(val);
		} catch (NumberFormatException e) {
			return dflt;
		}
	}

	public static long getLong(Dictionary<String, ?> dict, String key, long dflt) throws ConfigurationException {
		String val = getString(dict, key, null);
		if (val == null) {
			return dflt;
		}
		try {
			return Long.parseLong(val);
		} catch (NumberFormatException e) {
			return dflt;
		}
	}

	public static String getString(Dictionary<String, ?> dict, String key) {
		Object val = dict.get(key);
		if (val == null) {
			return null;
		}
		return val.toString().trim();
	}

	public static String getString(Dictionary<String, ?> dict, String key, String dflt) throws ConfigurationException {
		Object val = dict.get(key);
		if (val == null) {
			return dflt;
		}
		if (val instanceof String) {
			return ((String) val).trim();
		}
		throw new ConfigurationException(key, "must be a string!");
	}

	public static URI getURI(Dictionary<String, ?> dict, String key, String dflt) throws ConfigurationException {
		String val = getString(dict, key, dflt);
		if (val == null) {
			return null;
		}
		return URI.create(val);
	}

	public static void updateServiceProperties(Component comp, Object... props) {
		Dictionary<Object, Object> serviceProperties = comp.getServiceProperties();
		for (int i = 0; i < props.length; i += 2) {
			serviceProperties.put(props[i].toString(), props[i + 1]);
		}
		comp.setServiceProperties(serviceProperties);
	}
}
