/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.security.authentication.authservice.session.file;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

/**
 * Represents a single session.
 */
public class Session {
    private String m_userId;
    private String m_sessionId;
    private Map<String, String> m_context;

    /**
     * Creates a new {@link Session} instance.
     */
    public Session() {
        m_context = new HashMap<>();
    }

    /**
     * Creates a new {@link Session} instance.
     */
    public Session(String userId, String sessionId, Map<String, String> context) {
        m_userId = userId;
        m_sessionId = sessionId;
        m_context = context == null ? Collections.emptyMap() : context;
    }

    /**
     * @return the userId
     */
    public String getUserId() {
        return m_userId;
    }

    /**
     * @return the context
     */
    public Map<String, String> getContext() {
        return m_context;
    }

    /**
     * @return the sessionId
     */
    public String getSessionId() {
        return m_sessionId;
    }

    public void write(DataOutput out) throws IOException {
        out.writeUTF(m_userId);
        out.writeUTF(m_sessionId);
        out.writeInt(m_context.size());
        for (Entry<String, String> entry : m_context.entrySet()) {
            out.writeUTF(entry.getKey());
            out.writeUTF(entry.getValue());
        }
    }

    public void read(DataInput in) throws IOException {
        m_userId = in.readUTF();
        m_sessionId = in.readUTF();

        int size = in.readInt();
        m_context = new HashMap<>(size);
        for (int i = 0; i < size; i++) {
            String key = in.readUTF();
            String val = in.readUTF();
            m_context.put(key, val);
        }
    }

}
