/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.security.authentication.idprovider.local;

import static org.amdatu.security.authentication.idprovider.IdProviderConstants.PROVIDER_TYPE;
import static org.amdatu.security.authentication.idprovider.local.LocalIdProviderConfig.TYPE_LOCAL;

import java.util.Hashtable;

import org.amdatu.security.account.AccountAdmin;
import org.amdatu.security.authentication.idprovider.IdProvider;
import org.amdatu.security.authentication.idprovider.UserLookupService;
import org.apache.felix.dm.DependencyActivatorBase;
import org.apache.felix.dm.DependencyManager;
import org.osgi.framework.BundleContext;
import org.osgi.framework.Constants;
import org.osgi.service.cm.ManagedService;
import org.osgi.service.log.LogService;

/**
 * @author <a href="mailto:amdatu-developers@amdatu.org">Amdatu Project Team</a>
 */
public class Activator extends DependencyActivatorBase {
    private static final String PID = "org.amdatu.security.authentication.idprovider.local";

    @Override
    public void init(BundleContext context, DependencyManager dm) throws Exception {
        String[] ifaces = { IdProvider.class.getName(), ManagedService.class.getName() };

        Hashtable<String, Object> props = new Hashtable<String, Object>();
        props.put(Constants.SERVICE_PID, PID);
        props.put(PROVIDER_TYPE, TYPE_LOCAL);

        dm.add(createComponent()
            .setInterface(ifaces, props)
            .setImplementation(LocalIdProvider.class)
            .add(createServiceDependency().setService(UserLookupService.class).setRequired(true))
            .add(createServiceDependency().setService(AccountAdmin.class).setRequired(true))
            .add(createServiceDependency().setService(LogService.class).setRequired(false)));
    }

}
