/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.security.authentication.idprovider;

import java.util.Map;
import java.util.Optional;

/**
 * Provides a service that looks up a <em>local</em> user based on a set of credentials and returns
 * an identifier that can be used to retrieve and identify the same user in the future.
 * <p>
 * This service is used to make a connection between users from a (remote) identity provider and
 * users that are locally known.
 * </p>
 */
public interface UserLookupService {

    /**
     * Maps a user identified by the given credentials to a identifier that represents the user in
     * the local application.
     *
     * @param credentials the credentials that should provide enough information to identify
     *        a user in the system, cannot be <code>null</code> and should not be empty.
     * @return a user identifier, if the user was found or an empty Optional.
     */
    Optional<String> getUserId(Map<String, String> credentials);

}
