/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.security.tokenprovider.tests;

import static org.amdatu.testing.configurator.TestConfigurator.cleanUp;
import static org.amdatu.testing.configurator.TestConfigurator.configure;
import static org.amdatu.testing.configurator.TestConfigurator.createConfiguration;
import static org.amdatu.testing.configurator.TestConfigurator.createServiceDependency;
import static org.junit.Assert.assertEquals;

import java.util.HashMap;
import java.util.Map;

import org.amdatu.security.tokenprovider.TokenConstants;
import org.amdatu.security.tokenprovider.TokenProvider;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class JwtTokenProviderTest {
    private static final String PID = "org.amdatu.security.tokenprovider.jwt";

    private volatile TokenProvider m_tokenProvider;

    @Before
    public void setUp() throws Exception {
        configure(this)
            .add(createConfiguration(PID)
                .setSynchronousDelivery(true)
                .set("algorithm", "HS256")
                .set("issuer", "test token provider")
                .set("audience", "test token audience")
                .set("tokenValidityPeriod", 60 /* seconds */)
                .set("keyUri", "random:HS256"))
            .add(createServiceDependency()
                .setService(TokenProvider.class, "(type=jwt)")
                .setRequired(true))
            .apply();
    }

    @Test
    public void testGenerateToken() throws Exception {
        Map<String, String> attributes = new HashMap<>();
        attributes.put(TokenConstants.SUBJECT, "testuser");
        attributes.put("someotherkey", "somevalue");

        String token = m_tokenProvider.generateToken(attributes);

        Map<String, String> verified = m_tokenProvider.verifyToken(token);
        assertEquals(verified.get(TokenConstants.SUBJECT), "testuser");
        assertEquals(verified.get("someotherkey"), "somevalue");
    }

    @After
    public void cleanup() {
        cleanUp(this);
    }
}
